@@ -19,11 +19,17 @@
 Infrared Remote Control Properties for GNOME.
 '''
 
-def run(datadir):
+def run(args, datadir):
     '''
     Executes the properties dialog.
     '''
 
+    import logging
+
+    # Support full tracing when --debug switch is passed:
+    if '--debug' in args or '-d' in args:
+        logging.getLogger().setLevel(logging.NOTSET)
+
     # Integrate DBus with GLib main loop
     from dbus.mainloop.glib import DBusGMainLoop
     DBusGMainLoop(set_as_default=True)
@@ -33,17 +39,21 @@ def run(datadir):
 
     pygtk.require('2.0')
 
-    from gettext import gettext as _
+    from gettext               import gettext as _
     from gnome_lirc_properties import ui
-    from gtk import gdk, glade
 
-    import gobject, gtk, os.path
+    import gobject, gtk, gtk.gdk, os.path
 
+    # Setup defaut properties:
     gobject.threads_init()
     gobject.set_application_name(_('Infrared Remote Control Properties'))
     gtk.window_set_default_icon_name('gnome-lirc-properties')
 
-    gdk.threads_init()
+    # Enable thread support:
+    gtk.gdk.threads_init()
 
-    ui_filename = os.path.join(datadir, 'gnome-lirc-properties.glade')
-    return ui.RemoteControlProperties(glade.XML(ui_filename)).run()
+    # Load the user interface:
+    ui_filename = os.path.join(datadir, 'gnome-lirc-properties.ui')
+    builder = gtk.Builder()
+    builder.add_from_file(ui_filename)
+    return ui.RemoteControlProperties(builder, datadir).run()
