@@ -63,17 +63,20 @@ class PolicyKitService(dbus.service.Object):
 
         try:
             if sender:
-                kit = dbus.SystemBus().get_object('org.freedesktop.PolicyKit', '/')
-                kit = dbus.Interface(kit, 'org.freedesktop.PolicyKit')
+                kit = dbus.SystemBus().get_object('org.freedesktop.PolicyKit1', '/org/freedesktop/PolicyKit1/Authority')
+                kit = dbus.Interface(kit, 'org.freedesktop.PolicyKit1.Authority')
 
-                # Note that we don't use IsProcessAuthorized because we have
-                # no ways to get the PID of the front-end, so we're left
-                # with checking that its bus name is authorised instead
-		# See http://bugzilla.gnome.org/show_bug.cgi?id=540912
-                granted = kit.IsSystemBusNameAuthorized(action, sender, False)
+                # Note that we don't use CheckAuthorization with bus name
+                # details because we have no ways to get the PID of the
+                # front-end, so we're left with checking that its bus name
+                # is authorised instead
+                # See http://bugzilla.gnome.org/show_bug.cgi?id=540912
+                (granted, _, details) = kit.CheckAuthorization(
+                                ('system-bus-name', {'name': sender}),
+                                action, {}, dbus.UInt32(1), '', timeout=600)
                 logging.info('authorization of system bus name \'%s\': %r', sender, granted)
 
-                if 'yes' != granted:
+                if not granted:
                     raise AccessDeniedException('Session not authorized by PolicyKit')
 
         except AccessDeniedException:
@@ -186,7 +189,11 @@ class ExternalToolDriver(PolicyKitService):
         try:
             if -1 != os.waitpid(self.__pid, os.P_NOWAIT):
                 print 'Terminating child process %d...' % self.__pid
-                os.kill(self.__pid, signal.SIGTERM)
+                # Kill irrecord and its children and wait for left-overs
+                # FIXME use self.__pid not -self.__pid when irrecord is fixed
+                # https://bugzilla.redhat.com/show_bug.cgi?id=593704
+                os.kill(-self.__pid, signal.SIGTERM)
+                os.waitpid(self.__pid, os.P_WAIT)
 
         except OSError, ex:
             if ex.errno != errno.ESRCH:
@@ -367,11 +374,7 @@ class DetectParametersDriver(IrRecordDriver):
 
             self.RequestAction(
                 _('Press random buttons on your remote control.'),
-                _('When you press the Start button, it is very important '
-                  'that you press many different buttons and hold them down ' +
-                  'for approximately one second. Each button should move the ' +
-                  'progress bar by at least one step, but in no case by more ' +
-                  'than ten steps.'))
+                _('When you press the Start button, it is very important that you press many different buttons and hold them down for approximately one second. Each button should move the progress bar by at least one step, but in no case by more than ten steps.'))
 
             return
 
@@ -382,9 +385,7 @@ class DetectParametersDriver(IrRecordDriver):
         if line.startswith(self._token_wait_toggle_mask):
             self.RequestAction(
                 _('Press a button repeatedly as fast as possible.'),
-                _('Make sure you keep pressing the <b>same</b> button and that you ' +
-                  '<b>do not hold</b> the button down.\nWait a little between button ' +
-                  'presses if you cannot see any progress.'))
+                _('Make sure you keep pressing the <b>same</b> button and that you <b>do not hold</b> the button down.\nWait a little between button presses if you cannot see any progress.'))
 
             return
 
@@ -484,18 +485,21 @@ class BackendService(PolicyKitService):
 
     INTERFACE_NAME = 'org.gnome.LircProperties.Mechanism'
     SERVICE_NAME   = 'org.gnome.LircProperties.Mechanism'
-    IDLE_TIMEOUT   =  30
+    IDLE_TIMEOUT   =  300
 
     # These are extra fields set by our GUI:
 
     __re_receiver_directive = re.compile(r'^\s*RECEIVER_(VENDOR|MODEL)=')
 
-    # These are used by the Debian/Ubuntu packages, as of 2008-02-12.
-    # The "REMOTE_" prefix is made optional, since it only was introduced
-    # with lirc 0.8.3~pre1-0ubuntu4 of Hardy Heron.
-
-    __re_remote_directive = re.compile(r'^\s*(?:REMOTE_)?(DRIVER|DEVICE|MODULES|' +
-                                       r'LIRCD_ARGS|LIRCD_CONF|VENDOR|MODEL)=')
+    if config.STARTUP_STYLE is 'fedora':
+        __re_remote_directive = re.compile(r'^\s*(LIRC_DRIVER|LIRC_DEVICE|MODULES|' +
+                                           r'LIRCD_OPTIONS|LIRCD_CONF|VENDOR|MODEL)=')
+    else:
+        # These are used by the Debian/Ubuntu packages, as of 2008-02-12.
+        # The "REMOTE_" prefix is made optional, since it only was introduced
+        # with lirc 0.8.3~pre1-0ubuntu4 of Hardy Heron.
+        __re_remote_directive = re.compile(r'^\s*(?:REMOTE_)?(DRIVER|DEVICE|MODULES|' +
+                                           r'LIRCD_ARGS|LIRCD_CONF|VENDOR|MODEL)=')
     __re_start_lircd      = re.compile(r'^\s*START_LIRCD=')
 
     def __init__(self, connection=None, path='/'):
@@ -599,20 +603,21 @@ class BackendService(PolicyKitService):
                     print >> output, ('%s"%s"' % (match.group(0), ShellQuote.shellquote(value)))
                 continue
 
-            # Deal with the START_LIRCD line:
+            if config.STARTUP_STYLE is not 'fedora':
+                # Deal with the START_LIRCD line:
 
-            match = self.__re_start_lircd.match(line)
+                match = self.__re_start_lircd.match(line)
 
-            if match:
-                # pychecker says "Using a conditional statement with a constant value (true)",
-                # which is ridicilous, considering Python 2.4 doesn't have conditional statements
-                # yet (PEP 308, aka. 'true_value if condition else false_value') and the expression
-                # below ('condition and true_value or false_value') is the recommended aquivalent.
-                value = (start_lircd is None) and 'true' or start_lircd
-                start_lircd = None
+                if match:
+                    # pychecker says "Using a conditional statement with a constant value (true)",
+                    # which is ridicilous, considering Python 2.4 doesn't have conditional statements
+                    # yet (PEP 308, aka. 'true_value if condition else false_value') and the expression
+                    # below ('condition and true_value or false_value') is the recommended equivalent.
+                    value = (start_lircd is None) and 'true' or start_lircd
+                    start_lircd = None
 
-                print >> output, (match.group(0) + ShellQuote.shellquote(value))
-                continue
+                    print >> output, (match.group(0) + ShellQuote.shellquote(value))
+                    continue
 
             output.write(line)
 
@@ -622,17 +627,29 @@ class BackendService(PolicyKitService):
         if remote_values:
             print >> output, '\n# Remote settings required by gnome-lirc-properties'
         for key, value in remote_values.items():
-            print >> output, ('REMOTE_%s="%s"' % (key, ShellQuote.shellquote(value)))
+            if config.STARTUP_STYLE is not 'fedora':
+                print >> output, ('REMOTE_%s="%s"' % (key, ShellQuote.shellquote(value)))
+            else:
+                print >> output, ('%s="%s"' % (key, ShellQuote.shellquote(value)))
 
         if receiver_values:
             print >> output, '\n# Receiver settings required by gnome-lirc-properties'
         for key, value in receiver_values.items():
             print >> output, ('RECEIVER_%s="%s"' % (key, ShellQuote.shellquote(value)))
 
-        if start_lircd is not None:
+        if start_lircd is not None and config.STARTUP_STYLE is not 'fedora':
             print >> output, '\n# Daemon settings required by gnome-lirc-properties'
             print >> output, ('START_LIRCD=%s' % start_lircd)
 
+        if config.STARTUP_STYLE is 'fedora':
+            value = (start_lircd is None) and 'true' or start_lircd
+            start_lircd = None
+            if 'true' == value:
+                args = '/sbin/chkconfig', 'lirc', 'on'
+            else:
+                args = '/sbin/chkconfig', 'lirc', 'off'
+            os.spawnv(os.P_WAIT, args[0], args)
+
         # Replace old file with new contents:
 
         os.unlink(oldfile)
@@ -652,13 +669,22 @@ class BackendService(PolicyKitService):
 
         self._check_permission(sender)
 
-        remote_values = {
-            'DRIVER': driver,
-            'DEVICE': device,
-            'MODULES': modules,
-            'LIRCD_ARGS': '',
-            'LIRCD_CONF': '',
-        }
+        if config.STARTUP_STYLE is 'fedora':
+            remote_values = {
+                'LIRC_DRIVER': driver,
+                'LIRC_DEVICE': device,
+                'MODULES': modules,
+                'LIRCD_OPTIONS': '',
+                'LIRCD_CONF': '',
+            }
+        else:
+            remote_values = {
+                'DRIVER': driver,
+                'DEVICE': device,
+                'MODULES': modules,
+                'LIRCD_ARGS': '',
+                'LIRCD_CONF': '',
+            }
 
         receiver_values = {
             'VENDOR': vendor,
@@ -737,6 +763,7 @@ class BackendService(PolicyKitService):
 
         if match is None:
             # no statement found, create entirely new file:
+            print 'Dropping whole configuration file'
 
             if not contents:
                 contents  = '# This configuration has been automatically generated\n'
@@ -753,6 +780,7 @@ class BackendService(PolicyKitService):
             contents += include_statement
 
         elif match.group(1):
+            print 'Found directive, updating it'
             head = contents[:match.start()]
             tail = contents[match.end():]
             contents = (head + include_statement + tail)
@@ -779,10 +807,18 @@ class BackendService(PolicyKitService):
 	    raise AccessDeniedException
 
         if 'enable' == action:
-            self._write_hardware_configuration(start_lircd=True)
+            if config.STARTUP_STYLE is 'fedora':
+                args = '/sbin/chkconfig', 'lirc', 'on'
+                os.spawnv(os.P_WAIT, args[0], args)
+            else:
+                self._write_hardware_configuration(start_lircd=True)
 
         elif 'disable' == action:
-            self._write_hardware_configuration(start_lircd=False)
+            if config.STARTUP_STYLE is 'fedora':
+                args = '/sbin/chkconfig', 'lirc', 'off'
+                os.spawnv(os.P_WAIT, args[0], args)
+            else:
+                self._write_hardware_configuration(start_lircd=False)
 
         else:
             args = '/etc/init.d/lirc', action
@@ -812,28 +848,6 @@ class BackendService(PolicyKitService):
                                   configuration,
                                   keys)
 
-    @dbus.service.method(dbus_interface=INTERFACE_NAME,
-                         in_signature='s', out_signature='',
-                         sender_keyword='sender')
-    def InstallRemoteDatabase(self, filename, sender=None):
-        '''Update the customized receiver database.'''
-
-        # Copy the tarball with updates into our data folder
-        # to allow atomic replacement of the old tarball:
-        tarball = os.path.join(config.PACKAGE_DIR, 'remotes-update.tar.gz')
-
-        if not os.path.isdir(config.PACKAGE_DIR):
-            os.makedirs(config.PACKAGE_DIR)
-
-        shutil.copyfile(filename, tarball)
-
-        # Now practice the atomic replacement:
-        os.rename(tarball, config.LIRC_REMOTES_TARBALL)
-
-        # Finally adjust timestamps of the archive:
-        timestamps = os.path.getatime(filename), os.path.getmtime(filename)
-        os.utime(config.LIRC_REMOTES_TARBALL, timestamps)
-
 def get_service_bus():
     '''Retrieves a reference to the D-BUS system bus.'''
 
