@@ -19,21 +19,20 @@
 The main window of the application.
 '''
 
-import dbus, errno, gobject, gtk, gtk.gdk, gtk.glade, pango
+import dbus, errno, gobject, gtk, gtk.gdk, pango
 import httplib, locale, logging, os, subprocess
 
 from gettext               import gettext as _
-from gnome_lirc_properties import backend, config, lirc, model, hardware, policykit, net
+from gnome_lirc_properties import backend, config, lirc, model, hardware, policykit
 
 from gnome_lirc_properties.ui.common                import show_message, thread_callback
 from gnome_lirc_properties.ui.CustomConfiguration   import CustomConfiguration
-from gnome_lirc_properties.ui.ProgressWindow        import ProgressWindow
 from gnome_lirc_properties.ui.ReceiverChooserDialog import ReceiverChooserDialog
 
 class RemoteControlProperties(object):
     '''The main window.'''
 
-    def __init__(self, glade_xml):
+    def __init__(self, builder, datadir):
         # Prevent UI changes from being written back to configuration files:
         #
         # Configuration files only are written when this field is zero.
@@ -43,8 +42,9 @@ class RemoteControlProperties(object):
         self.__configuration_level = -1
 
         # Initialize models and views.
-        self.__ui = glade_xml
-        self.__ui.signal_autoconnect(self)
+        self.__ui = builder
+        self.__datadir = datadir
+        self.__ui.connect_signals(self)
 
         self.__custom_configuration = None
         self.__receiver_chooser = None
@@ -74,7 +74,7 @@ class RemoteControlProperties(object):
 
         # pylint: disable-msg=W0201,E1101
 
-        receivers_db = hardware.HardwareDatabase(self.__ui.relative_file('receivers.conf'))
+        receivers_db = hardware.HardwareDatabase(os.path.join(self.__datadir, 'receivers.conf'))
         self.__remotes_db = lirc.RemotesDatabase()
 
         self.__hardware_manager = hardware.HardwareManager(receivers_db)
@@ -97,9 +97,8 @@ class RemoteControlProperties(object):
         selected_remote = self.selected_remote
 
         self.__remotes_db.clear()
-        self.__remotes_db.load(self.__ui.relative_file('linux-input-layer-lircd.conf'))
+        self.__remotes_db.load(os.path.join(self.__datadir, 'linux-input-layer-lircd.conf'))
         self.__remotes_db.load_folder()
-        self.__remotes_db.load_tarball()
 
         self.__remote_vendors.clear()
         self.__remote_vendors.load(self.__remotes_db)
@@ -121,7 +120,7 @@ class RemoteControlProperties(object):
         self.__key_listener.connect('key-pressed', self.__on_lirc_key_pressed)
 
     def __lookup_widgets(self):
-        '''Initialize widget attributes from Glade file.'''
+        '''Initialize widget attributes from GtkBuilder file.'''
 
         # This method is more robust than looking up and assigning widgets
         # manually, but it also completly screws up pychecker and pylint. For
@@ -159,11 +158,11 @@ class RemoteControlProperties(object):
 
         for widget_id in widget_list:
             attr = '_%s__%s' % (self.__class__.__name__, widget_id)
-            widget = self.__ui.get_widget(widget_id)
+            widget = self.__ui.get_object(widget_id)
             assert widget is not None, widget_id
             setattr(self, attr, widget)
 
-        self.__dialog = self.__ui.get_widget('lirc_properties_dialog')
+        self.__dialog = self.__ui.get_object('lirc_properties_dialog')
         self.__entry_device = self.__combo_device.get_child()
         self.__table_receiver_selection.set_row_spacing(2, 0)
 
@@ -208,7 +207,10 @@ class RemoteControlProperties(object):
         for widget in (
             self.__combo_receiver_vendor_list, self.__combo_receiver_product_list,
             self.__combo_remote_vendor_list, self.__combo_remote_product_list):
-            widget.get_cells()[0].set_property('ellipsize', pango.ELLIPSIZE_END)
+            renderer = gtk.CellRendererText()
+            renderer.set_property('ellipsize', pango.ELLIPSIZE_END)
+            widget.pack_start(renderer)
+            widget.add_attribute(renderer, "text", 0)
 
     def __setup_authorization(self):
         '''Initialize authorization facilities.'''
@@ -242,10 +244,8 @@ class RemoteControlProperties(object):
         return (
             gtk.RESPONSE_ACCEPT == show_message(self.__dialog,
             _('Invalid IR Configuration'),
-            _('Your configuration files seems to be incorrect. ' +
-              'Should this program try to restore your settings, ' +
-              'for a %s %s remote?') % (
-            remote.vendor, remote.product), buttons=responses))
+            _('Your configuration files seems to be incorrect. Should this program try to restore your settings, for a %s %s remote?') % 
+            (remote.vendor, remote.product), buttons=responses))
 
     def __restore_hardware_settings(self):
         '''Restore hardware settings from configuration files.'''
@@ -299,11 +299,20 @@ class RemoteControlProperties(object):
         # reason the device node's name is stored in REMOTE_DEVICE, instead
         # of RECEIVER_DEVICE.
         #
-        self.selected_receiver = (
-            settings.get('RECEIVER_VENDOR'),
-            settings.get('RECEIVER_MODEL'),
-            settings.get('REMOTE_DEVICE'),
-        )
+        # The setting is called LIRC_DEVICE is Fedora.
+        #
+        if config.STARTUP_STYLE is 'fedora':
+            self.selected_receiver = (
+                settings.get('RECEIVER_VENDOR'),
+                settings.get('RECEIVER_MODEL'),
+                settings.get('LIRC_DEVICE'),
+            )
+        else:
+            self.selected_receiver = (
+                settings.get('RECEIVER_VENDOR'),
+                settings.get('RECEIVER_MODEL'),
+                settings.get('REMOTE_DEVICE'),
+            )
 
         # Try to select configured remote vendor:
         self.selected_remote = (
@@ -324,9 +333,8 @@ class RemoteControlProperties(object):
 
         else:
             self.__label_preview_result.hide()
-            self.__label_preview_status.set_markup(_('<b>Warning:</b> Remote control daemon ' +
-                                                     'not running. Cannot test buttons.\n' + 
-                                                     'This could be due to a configuration error. Try changing the configuration.'))
+            self.__label_preview_status.set_markup(
+                _('<b>Warning:</b> Remote control daemon not running. Cannot test buttons.\nThis could be due to a configuration error. Try changing the configuration.'))
 
     # pylint: disable-msg=W0613,R0913
     def __on_lirc_key_pressed(self, listener, remote, repeat, name, code):
@@ -367,78 +375,6 @@ class RemoteControlProperties(object):
         if use_supplied and self.supplied_remote:
             self.selected_remote = self.supplied_remote
 
-    def _on_button_download_clicked(self, button=None):
-        '''Handle clicks on the auto-detection button.'''
-
-        @thread_callback
-        def on_download_progress(progress, total, action):
-            '''Handle progress reports from download service.'''
-
-            args = (
-                locale.format(percent='%.1f', grouping=True, value=progress/1024.0),
-                locale.format(percent='%.1f', grouping=True, value=total/1024.0))
-            message = (
-                total > 0 and _('%s of %s KiB retrieved...') % args
-                           or _('%s KiB retrieved...') % args[0])
-
-            progress_window.detail = action
-            progress_window.update(progress, total, message)
-
-        @thread_callback
-        def on_download_success(content, headers):
-            '''Handle finished downloads.'''
-
-            self.__dialog.set_sensitive(True)
-            progress_window.hide()
-
-            if 'application/x-gzip' == headers.get('content-type'):
-                try:
-                    backend.get_service().InstallRemoteDatabase(content.name)
-                    self.__update_remotes_db()
-
-                except dbus.DBusException, ex:
-                    show_message(self.__dialog, progress_window.title, ex.message)
-
-            elif httplib.NOT_MODIFIED == getattr(content, 'code', None):
-                show_message(self.__dialog, progress_window.title,
-                             details=_('No updates available. Your remote control configuration ' +
-                                       'files are already up-to-date.'),
-                             message_type=gtk.MESSAGE_INFO)
-
-            else:
-                show_message(self.__dialog, progress_window.title,
-                             _('Download of updated remote control configurations failed.'))
-
-        @thread_callback
-        def on_download_failure(message):
-            '''Handle failure reports from download service.'''
-
-            self.__dialog.set_sensitive(True)
-            progress_window.hide()
-
-            show_message(self.__dialog, progress_window.title, message)
-
-        self.__dialog.set_sensitive(False)
-        progress_window = ProgressWindow(self.__ui)
-        progress_window.show(self.__dialog, _('Updating Remote Configuration Files'))
-
-        gtk.gdk.threads_leave()
-
-        try:
-            timestamp = (
-                os.path.isfile(config.LIRC_REMOTES_TARBALL) and
-                os.path.getmtime(config.LIRC_REMOTES_TARBALL) or
-                None)
-
-            net.retrieve_tarball(tarball_uri=config.URI_UPDATES,
-                                 progress_callback=on_download_progress,
-                                 success_callback=on_download_success,
-                                 failure_callback=on_download_failure,
-                                 reference_time=timestamp)
-
-        finally:
-            gtk.gdk.threads_enter()
-
     # pylint: disable-msg=C0103
     def _on_radiobutton_other_remote_size_allocate(self, widget, alloc):
         '''
@@ -603,6 +539,11 @@ class RemoteControlProperties(object):
             # highlight supplied IR remote:
             if self.supplied_remote:
                 self.selected_remote = self.supplied_remote
+                self.__radiobutton_supplied_remote.set_sensitive(True)
+                self.__radiobutton_supplied_remote.set_active(True)
+            else:
+                self.__radiobutton_other_remote.set_active(True)
+                self.__radiobutton_supplied_remote.set_sensitive(False)
 
         finally:
             #  thaw configuration updates:
@@ -665,10 +606,7 @@ class RemoteControlProperties(object):
             if (gtk.RESPONSE_REJECT ==
                 show_message(self.__dialog,
                              _('No IR Receivers Found'),
-                             _('Could not find any IR receiver. Is your device attached?\n\n' +
-                             'Note that some devices, such as homebrew serial port ' +
-                             'receivers must be selected manually since there is no ' +
-                             'way to detect them automatically.'),
+                             _('Could not find any IR receiver. Is your device attached?\n\nNote that some devices, such as homebrew serial port receivers must be selected manually since there is no way to detect them automatically.'),
                              buttons=responses)):
 
                 self._on_button_auto_detect_clicked()
@@ -787,7 +725,13 @@ class RemoteControlProperties(object):
         self._on_search_progress(None, 0, _('Searching for remote controls...'))
 
         if not self.__receiver_chooser:
-            self.__receiver_chooser = ReceiverChooserDialog(self.__ui)
+            receiver_filename = os.path.join(self.__datadir, 'gnome-lirc-properties-receiver.ui')
+            receiver_builder = gtk.Builder()
+            receiver_builder.add_from_file(receiver_filename)
+            dialog = receiver_builder.get_object('receiver_chooser_dialog')
+            dialog.set_transient_for(self.__dialog)
+            dialog.connect('response', self._on_receiver_chooser_dialog_response)
+            self.__receiver_chooser = ReceiverChooserDialog(receiver_builder)
 
         self.__receiver_chooser.reset()
 
@@ -803,7 +747,12 @@ class RemoteControlProperties(object):
         '''Handle clicks on the auto-detection's "Custom Configuration" button.'''
 
         if not self.__custom_configuration:
-            self.__custom_configuration = CustomConfiguration(self.__ui)
+            custom_filename = os.path.join(self.__datadir, 'gnome-lirc-properties-custom-config.ui')
+            custom_builder = gtk.Builder()
+            custom_builder.add_from_file(custom_filename)
+            dialog = custom_builder.get_object('custom_configuration')
+            dialog.set_transient_for(self.__dialog)
+            self.__custom_configuration = CustomConfiguration(custom_builder)
 
         self.__custom_configuration.run(self.selected_receiver,
                                         self.selected_device,
@@ -871,10 +820,10 @@ class RemoteControlProperties(object):
 
     def _set_widgets_locked(self, locked):
         '''Gray (or ungray) widgets which require PolicyKit authorization.'''
-        self.__ui.get_widget('vbox').set_sensitive(not locked)
+        self.__ui.get_object('vbox').set_sensitive(not locked)
 
         # Gray out the Unlock button if we are now already unlocked:
-        button = self.__ui.get_widget('unlockbutton')
+        button = self.__ui.get_object('unlockbutton')
         button.set_sensitive(locked)
 
     # pylint: disable-msg=R0201
@@ -890,8 +839,7 @@ class RemoteControlProperties(object):
 
         except OSError, ex:
             if errno.ENOENT == ex.errno:
-                error_message = _('Cannot display help since the GNOME Help ' +
-                                  'Browser ("yelp") cannot be found.')
+                error_message = _('Cannot display help since the GNOME Help Browser ("yelp") cannot be found.')
 
             else:
                 error_message = _('Cannot display help for unexpected reason: %s') % ex.strerror
@@ -1059,6 +1007,14 @@ class RemoteControlProperties(object):
         '''Retrieve the currently selected device.'''
         return self.__entry_device.get_text().strip()
 
+    def __requires_device_node(self, driver):
+        '''Check whether the LIRC driver used requires a device node'''
+        # You can check this by hand by opening the daemons/hw_*.c drivers
+        # in lirc, and checking for ".device" being used from the
+        # struct hardware
+        no_device_node = ('atilibusb', 'awlibusb', 'caraca', 'commandir', 'dfclibusb')
+        return driver not in no_device_node
+
     def __set_selected_device(self, device_node):
         '''Change the currently selected device.'''
 
@@ -1084,9 +1040,9 @@ class RemoteControlProperties(object):
 
             tree_iter = tree_model.iter_next(tree_iter)
 
-        # device node not found in combo box, fallback to modify its entry:
+        # device node required but not found in combo box, fallback to modify its entry:
         markup = (
-            receiver and not device_node and
+            receiver and not device_node and self.__requires_device_node(receiver.lirc_driver) and
             _('<b>Warning:</b> Cannot find such receiver.') or '')
 
         self.__entry_device.set_text(device_node or '')
